@@ -15,12 +15,13 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *)
+*)
 open Ocsigen_extensions
 
 (* Displaying of a local file or directory. Currently used in
    staticmod and eliom_predefmod*)
 
+let section = Lwt_log.Section.make "ocsigen:local-file"
 exception Failed_403
 exception Failed_404
 exception NotReadableDirectory
@@ -28,7 +29,7 @@ exception NotReadableDirectory
 
 (* Policies for following symlinks *)
 type symlink_policy =
-    stat:Unix.LargeFile.stats -> lstat:Unix.LargeFile.stats -> bool
+  stat:Unix.LargeFile.stats -> lstat:Unix.LargeFile.stats -> bool
 
 let never_follow_symlinks : symlink_policy =
   fun ~stat ~lstat -> false
@@ -54,9 +55,6 @@ let check_symlinks_aux
 (* Check that there are no invalid symlinks in the directories leading to
    [filename]. Paths upwards [no_check_for] are not checked. *)
 let rec check_symlinks_parent_directories ~filename ~no_check_for (policy : symlink_policy) =
-  (* Ocsigen_messages.debug
-    (fun () -> Printf.sprintf "Checking %s (until %s)"
-       filename (match no_check_for with None -> "" | Some s -> s)); *)
   if filename = "/" || filename = "." || Some filename = no_check_for then
     true
   else
@@ -92,9 +90,9 @@ let check_symlinks ~no_check_for ~filename policy =
       check_symlinks_parent_directories filename no_check_for policy
   in
   match policy with
-    | AlwaysFollowSymlinks -> true
-    | DoNotFollowSymlinks -> aux never_follow_symlinks
-    | FollowSymlinksIfOwnerMatch -> aux follow_symlinks_if_owner_match
+  | AlwaysFollowSymlinks -> true
+  | DoNotFollowSymlinks -> aux never_follow_symlinks
+  | FollowSymlinksIfOwnerMatch -> aux follow_symlinks_if_owner_match
 
 let check_dotdot =
   let regexp = Netstring_pcre.regexp "(/\\.\\./)|(/\\.\\.$)" in
@@ -108,19 +106,17 @@ let check_dotdot =
 let can_send filename request =
   let filename =
     Neturl.join_path (Neturl.norm_path (Neturl.split_path filename)) in
-  Ocsigen_messages.debug
-    (fun () -> Printf.sprintf "--LocalFiles: checking if file %s can be sent"
-       filename);
+  Lwt_log.ign_info_f ~section "checking if file %s can be sent" filename;
   let matches arg =
     Netstring_pcre.string_match (Ocsigen_extensions.do_not_serve_to_regexp arg)
       filename 0 <> None
   in
   if matches request.do_not_serve_403 then (
-    Ocsigen_messages.debug2 "--LocalFiles: this file is forbidden";
+    Lwt_log.ign_info ~section "this file is forbidden";
     raise Failed_403)
   else
     if matches request.do_not_serve_404 then (
-      Ocsigen_messages.debug2 "--LocalFiles: this file must be hidden";
+      Lwt_log.ign_info ~section "this file must be hidden";
       raise Failed_404)
 
 
@@ -157,8 +153,7 @@ let resolve ?no_check_for ~request ~filename () =
       filename
   in
   try
-    Ocsigen_messages.debug
-      (fun () -> "--LocalFiles: Testing \""^filename^"\".");
+    Lwt_log.ign_info_f ~section "Testing \"%s\"." filename;
     let stat = Unix.LargeFile.stat filename in
     let (filename, stat) =
       if stat.Unix.LargeFile.st_kind = Unix.S_DIR then
@@ -166,9 +161,9 @@ let resolve ?no_check_for ~request ~filename () =
           (* In this case, [filename] is a directory but this is not visible in
              its name as there is no final slash. We signal this fact to
              Ocsigen, which will then issue a 301 redirection to "filename/" *)
-          Ocsigen_messages.debug
-            (fun () -> "--LocalFiles: "^filename^" is a directory");
-          raise (Ocsigen_extensions.Ocsigen_Is_a_directory request)
+          Lwt_log.ign_info_f ~section "LocalFiles: %s is a directory" filename;
+          raise (Ocsigen_extensions.Ocsigen_Is_a_directory
+                   (Ocsigen_extensions.new_url_of_directory_request request))
         end
 
         else
@@ -176,18 +171,15 @@ let resolve ?no_check_for ~request ~filename () =
             | [] ->
                 (* No suitable index, we try to list the directory *)
                 if request.request_config.list_directory_content then (
-                  Ocsigen_messages.debug2
-                    "--LocalFiles: Displaying directory content";
+                  Lwt_log.ign_info ~section "Displaying directory content";
                   (filename, stat))
                 else (
                   (* No suitable index *)
-                  Ocsigen_messages.debug2 "--LocalFiles: No index and no listing";
+                  Lwt_log.ign_info ~section "No index and no listing";
                   raise NotReadableDirectory)
             | e :: q ->
                 let index = filename ^ e in
-                Ocsigen_messages.debug
-                  (fun () -> "--LocalFiles: Testing \""^index
-                     ^"\" as possible index.");
+                Lwt_log.ign_info_f ~section "Testing \"%s\" as possible index." index;
                 try
                   (index, Unix.LargeFile.stat index)
                 with
@@ -198,17 +190,15 @@ let resolve ?no_check_for ~request ~filename () =
     in
     if not (check_dotdot ~filename)
     then
-      (Ocsigen_messages.debug
-         (fun () -> "--Filenames cannot contain .. as in \""^filename^"\".");
+      (Lwt_log.ign_info_f ~section "Filenames cannot contain .. as in \"%s\"." filename;
        raise Failed_403)
     else if check_symlinks ~filename ~no_check_for
-      request.request_config.follow_symlinks
+        request.request_config.follow_symlinks
     then (
-        can_send filename request.request_config;
+      can_send filename request.request_config;
       (* If the previous function did not fail, we are authorized to
          send this file *)
-      Ocsigen_messages.debug
-        (fun () -> "--LocalFiles: Returning \""^filename^"\".");
+        Lwt_log.ign_info_f ~section "Returning \"%s\"." filename;
       if stat.Unix.LargeFile.st_kind = Unix.S_REG then
         RFile filename
       else if stat.Unix.LargeFile.st_kind = Unix.S_DIR then
@@ -218,28 +208,27 @@ let resolve ?no_check_for ~request ~filename () =
     else (
       (* [filename] is accessed through as symlink which we should not
          follow according to the current policy *)
-      Ocsigen_messages.debug
-        (fun () -> "--Failed symlink check for \""^filename^"\".");
+      Lwt_log.ign_info_f ~section "Failed symlink check for \"%s\"." filename;
       raise Failed_403)
   with
-    (* We can get an EACCESS here, if are missing some rights on a directory *)
-    | Unix.Unix_error (Unix.EACCES,_,_) -> raise Failed_403
-    | Unix.Unix_error (Unix.ENOENT,_,_) -> raise Failed_404
+  (* We can get an EACCESS here, if are missing some rights on a directory *)
+  | Unix.Unix_error (Unix.EACCES,_,_) -> raise Failed_403
+  | Unix.Unix_error (Unix.ENOENT,_,_) -> raise Failed_404
 
 
 (* Given a local file or directory, we retrieve its content *)
 let content ~request ~file =
   try
     match file with
-      | RDir dirname ->
-          Ocsigen_senders.Directory_content.result_of_content
-            (dirname, request.request_info.ri_full_path)
-      | RFile filename ->
-          Ocsigen_senders.File_content.result_of_content
-            (filename,
-             request.request_config.charset_assoc,
-             request.request_config.mime_assoc
-            )
+    | RDir dirname ->
+      Ocsigen_senders.Directory_content.result_of_content
+        (dirname, Ocsigen_request_info.full_path request.request_info)
+    | RFile filename ->
+      Ocsigen_senders.File_content.result_of_content
+        (filename,
+         request.request_config.charset_assoc,
+         request.request_config.mime_assoc
+        )
 
   with
-    | Unix.Unix_error (Unix.EACCES,_,_) -> raise Failed_403
+  | Unix.Unix_error (Unix.EACCES,_,_) -> raise Failed_403
